@@ -1,4 +1,4 @@
-//@line 39 "/export/storage/mozilla/packages/BUILD/mozilla/browser/components/preferences/cookies.js"
+//@line 39 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/components/preferences/cookies.js"
 
 const nsICookie = Components.interfaces.nsICookie;
 
@@ -22,17 +22,7 @@ var gCookiesWindow = {
     this._bundle = document.getElementById("bundlePreferences");
     this._tree = document.getElementById("cookiesList");
     
-    this._loadCookies();
-    this._tree.treeBoxObject.view = this._view;
-    this.sort("rawHost");
-    if (this._view.rowCount > 0) 
-      this._tree.view.selection.select(0);
-
-    if ("arguments" in window && window.arguments[0] &&
-        window.arguments[0].filterString)
-      this.setFilter(window.arguments[0].filterString);
-    
-    this._saveState();
+    this._populateList(true);
       
     document.getElementById("filter").focus();
   },
@@ -45,6 +35,30 @@ var gCookiesWindow = {
     os.removeObserver(this, "perm-changed");
   },
   
+  _populateList: function (aInitialLoad)
+  {
+    this._loadCookies();
+    this._tree.treeBoxObject.view = this._view;
+    if (aInitialLoad)
+      this.sort("rawHost");
+    if (this._view.rowCount > 0) 
+      this._tree.view.selection.select(0);
+
+    if (aInitialLoad) {
+      if ("arguments" in window && window.arguments[0] &&
+          window.arguments[0].filterString)
+      {
+        this.setFilter(window.arguments[0].filterString);
+      }
+    }
+    else {
+      if (document.getElementById("filter").value != "")
+        this.filter();
+    }
+
+    this._saveState();
+  },
+  
   _cookieEquals: function (aCookieA, aCookieB, aStrippedHost)
   {
     return aCookieA.rawHost == aStrippedHost &&
@@ -73,6 +87,13 @@ var gCookiesWindow = {
       this._tree.treeBoxObject.rowCountChanged(0, -oldRowCount);
       this._view.selection.clearSelection();
     }
+    else if (aData == "reload") {
+      // first, clear any existing entries
+      this.observe(aCookie, aTopic, "cleared");
+
+      // then, reload the list
+      this._populateList(false);
+    }
     
     // We don't yet handle aData == "deleted" - it's a less common case
     // and is rather complicated as selection tracking is difficult
@@ -563,7 +584,7 @@ var gCookiesWindow = {
   
   deleteCookie: function () 
   { 
-//@line 651 "/export/storage/mozilla/packages/BUILD/mozilla/browser/components/preferences/cookies.js"
+//@line 672 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/components/preferences/cookies.js"
     var seln = this._view.selection;
     var tbo = this._tree.treeBoxObject;
     
@@ -706,8 +727,7 @@ var gCookiesWindow = {
     // Revert to single-select in the tree
     this._tree.setAttribute("seltype", "single");
     
-    // Clear the Filter and the Tree Display
-    document.getElementById("filter").value = "";
+    // Clear the Tree Display
     this._view._filtered = false;
     this._view._rowCount = 0;
     this._tree.treeBoxObject.rowCountChanged(0, -this._view._filterSet.length);
@@ -742,8 +762,6 @@ var gCookiesWindow = {
     this._lastSelectedRanges = [];
 
     document.getElementById("cookiesIntro").value = this._bundle.getString("cookiesAll");
-    document.getElementById("clearFilter").disabled = true;
-    document.getElementById("filter").focus();
   },
   
   _cookieMatchesFilter: function (aCookie)
@@ -791,68 +809,49 @@ var gCookiesWindow = {
         this._openIndices.push(i);
     }
   },
-  
-  _filterTimeout: -1,
-  onFilterInput: function ()
-  {
-    if (this._filterTimeout != -1)
-      clearTimeout(this._filterTimeout);
-   
-    function filterCookies()
-    {
-      var filter = document.getElementById("filter").value;
-      if (filter == "") {
-        gCookiesWindow.clearFilter();
-        return;
-      }        
-      var view = gCookiesWindow._view;
-      view._filterSet = gCookiesWindow._filterCookies(filter);
-      if (!view._filtered) {
-        // Save Display Info for the Non-Filtered mode when we first
-        // enter Filtered mode. 
-        gCookiesWindow._saveState();
-        view._filtered = true;
-      }
-      // Move to multi-select in the tree
-      gCookiesWindow._tree.setAttribute("seltype", "multiple");
-      
-      // Clear the display
-      var oldCount = view._rowCount;
-      view._rowCount = 0;
-      gCookiesWindow._tree.treeBoxObject.rowCountChanged(0, -oldCount);
-      // Set up the filtered display
-      view._rowCount = view._filterSet.length;
-      gCookiesWindow._tree.treeBoxObject.rowCountChanged(0, view.rowCount);
-      
-      // if the view is not empty then select the first item
-      if (view.rowCount > 0)
-        view.selection.select(0);
 
-      document.getElementById("cookiesIntro").value = gCookiesWindow._bundle.getString("cookiesFiltered");
-      document.getElementById("clearFilter").disabled = false;
-    }
-    window.filterCookies = filterCookies;
-    this._filterTimeout = setTimeout("filterCookies();", 500);
-  },
-  
-  onFilterKeyPress: function (aEvent)
+  filter: function ()
   {
     var filter = document.getElementById("filter").value;
-    if (aEvent.keyCode == 27 && filter != "") // ESC key
-      this.clearFilter();
+    if (filter == "") {
+      gCookiesWindow.clearFilter();
+      return;
+    }
+    var view = gCookiesWindow._view;
+    view._filterSet = gCookiesWindow._filterCookies(filter);
+    if (!view._filtered) {
+      // Save Display Info for the Non-Filtered mode when we first
+      // enter Filtered mode.
+      gCookiesWindow._saveState();
+      view._filtered = true;
+    }
+    // Move to multi-select in the tree
+    gCookiesWindow._tree.setAttribute("seltype", "multiple");
+
+    // Clear the display
+    var oldCount = view._rowCount;
+    view._rowCount = 0;
+    gCookiesWindow._tree.treeBoxObject.rowCountChanged(0, -oldCount);
+    // Set up the filtered display
+    view._rowCount = view._filterSet.length;
+    gCookiesWindow._tree.treeBoxObject.rowCountChanged(0, view.rowCount);
+
+    // if the view is not empty then select the first item
+    if (view.rowCount > 0)
+      view.selection.select(0);
+
+    document.getElementById("cookiesIntro").value = gCookiesWindow._bundle.getString("cookiesFiltered");
   },
-  
+
+  setFilter: function (aFilterString) {
+    document.getElementById("filter").value = aFilterString;
+    this.filter();
+  },
+
   focusFilterBox: function ()
-  { 
+  {
     var filter = document.getElementById("filter");
     filter.focus();
     filter.select();
-  },
-
-  setFilter: function (aFilterString)
-  {
-    document.getElementById("filter").value = aFilterString;
-    this.onFilterInput();
   }
 };
-
